@@ -123,7 +123,7 @@ class CloudPods:
             return None
 
     @enter_and_leave_function
-    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets_list, vm_name, sku,count=1,reset_new_password=""):
+    def create_server_by_guest_image(self,guest_image_id,disk_image_id,arch, disk_size, disks, nets_list, vm_name, sku,count=1,reset_new_password="",hypervisor="kvm"):
         if arch == "x86_64":
             bios="BIOS"
         else:
@@ -132,6 +132,7 @@ class CloudPods:
         server = {
             "auto_start": True,
             "generate_name": vm_name,
+            "hypervisor": hypervisor,
             "disable_delete": False,
             "__count__": 1,
             "disks": [{"disk_type": "sys", "index": 0, "backend": "local", "size": disk_size, "image_id": disk_image_id,
@@ -142,6 +143,7 @@ class CloudPods:
             "deploy_telegraf": True,
             "os_arch": arch,
             "nets": nets,
+            "prefer_region": "default",
             "bios": bios
         }
         if reset_new_password:
